# Define pkgdocdir for releases that don't define it already
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}
%global _perldocdir %{_docdir}/perl-qpid-messaging-%{version}
%global _pythondocdir %{_docdir}/python-qpid-messaging-%{version}

# We ship a .pc file but don't need to depend on pkg-config
%global __requires_exclude pkg-config
%global __provides_exclude_from ^(%{python_sitearch}/.*\\.so|%{_libdir}/.libqmf*)$
%global proton_min_ver 0.16.0

Name:          qpid-cpp
Version:       1.36.0
Release:       18%{?dist}
Summary:       Libraries for Qpid C++ client applications
License:       ASL 2.0
URL:           http://qpid.apache.org

Source0:       http://www.apache.org/dist/qpid/cpp/%{version}/%{name}-%{version}.tar.gz
Source4:       qpidd.sasldb
Patch0:        mrg.patch
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
Patch1:        0001-NO-JIRA-qpidd.service-file-for-use-on-Fedora.patch
%endif
%if 0%{?fedora}
Patch2:        0002-NO-JIRA-Allow-overriding-the-Perl-install-location.patch
Patch3:        0003-NO-JIRA-Allow-overriding-the-Ruby-install-location.patch
%endif

ExcludeArch:   ppc s390
BuildRequires: boost-devel
BuildRequires: boost-filesystem
BuildRequires: boost-program-options
BuildRequires: cmake
BuildRequires: cyrus-sasl
BuildRequires: cyrus-sasl-devel
BuildRequires: cyrus-sasl-lib
%if (0%{?rhel} && 0%{?rhel} < 7)
BuildRequires: db4-devel
%endif
BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: libaio-devel
%if 0%{?fedora}
BuildRequires: libdb4-cxx-devel
%endif
%if (0%{?rhel} && 0%{?rhel} == 7)
BuildRequires: libdb-cxx-devel
%endif
%ifnarch s390 s390x
BuildRequires: libibverbs-devel
BuildRequires: librdmacm-devel
%endif
BuildRequires: libuuid-devel
BuildRequires: make
BuildRequires: nspr-devel
BuildRequires: nss-devel
%if 0%{?fedora}
BuildRequires: perl-devel
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl-generators
%endif
BuildRequires: pkgconfig
BuildRequires: python
BuildRequires: python-devel
BuildRequires: python-setuptools
BuildRequires: qpid-proton-c-devel >= %{proton_min_ver}
BuildRequires: ruby
BuildRequires: ruby-devel
BuildRequires: swig
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} < 7)
BuildRequires: xerces-c-devel
BuildRequires: xqilla-devel
%endif

# Filter bogus libcqpid_perl.so() Provides, this is intentional rpm-build
# feature, bug #1309664
%global __provides_exclude_from %{?__provides_exclude_from:%{__provides_exclude_from}|}^%{perl_vendorarch}/auto/.*\\.so$


%description

Run-time libraries for AMQP client applications developed using Qpid
C++. Clients exchange messages with an AMQP message broker using
the AMQP protocol.


%package client
Summary:   Libraries for Qpid C++ client applications
%if 0%{?fedora}
Provides:  qpid(cpp-client)%{?_isa} = %{version}-%{release}
%endif
Obsoletes: qpidc
Obsoletes: %{name}-client-ssl

Requires:  boost-filesystem
Requires:  boost-program-options
Requires:  boost-system
Requires:  qpid-proton-c%{?_isa} >= %{proton_min_ver}

%if (0%{?rhel} && 0%{?rhel} < 7)
Requires:  initscripts
Requires(post):/sbin/chkconfig
Requires(preun):/sbin/chkconfig
Requires(preun):/sbin/service
Requires(postun):/sbin/service
%endif

%description client
Run-time libraries for AMQP client applications developed using Qpid
C++. Clients exchange messages with an AMQP message broker using
the AMQP protocol.

%files client
%defattr(-,root,root,-)
%doc LICENSE.txt
%doc NOTICE.txt
%doc README.md
%doc INSTALL.txt
%{_libdir}/libqpidcommon.so.*
%{_libdir}/libqpidclient.so.*
%{_libdir}/libqpidtypes.so.*
%{_libdir}/libqpidmessaging.so.*
%dir %{_libdir}/qpid
%ifnarch s390 s390x
%dir %{_libdir}/qpid/client
%exclude %{_libdir}/qpid/client/rdmaconnector.so*
%endif
%dir %{_sysconfdir}/qpid
%config(noreplace) %{_sysconfdir}/qpid/qpidc.conf

%post client
/sbin/ldconfig

%postun client
/sbin/ldconfig


%package client-devel
Summary:   Header files, documentation and testing tools for developing Qpid C++ clients
%if 0%{?fedora}
Provides:  qpid(cpp-client-devel)%{?_isa} = %{version}-%{release}
Requires:  qpid(cpp-client)%{?_isa} = %{version}-%{release}
%endif
Requires:  %{name}-client = %{version}-%{release}
Requires:  boost-devel
Requires:  boost-filesystem
Requires:  boost-program-options
Requires:  libuuid-devel
Requires:  python
Obsoletes: qpidc-devel
Obsoletes: qpidc-perftest

%description client-devel
Libraries and header files for developing AMQP clients in C++ using Qpid.
Qpid implements the AMQP messaging specification.

%files client-devel
%defattr(-,root,root,-)
%dir %{_includedir}/qpid
%{_includedir}/qpid/*.h
%{_includedir}/qpid/qpid.i
%{_includedir}/qpid/swig_perl_typemaps.i
%{_includedir}/qpid/swig_python_typemaps.i
%{_includedir}/qpid/swig_ruby_typemaps.i
%{_includedir}/qpid/client
%{_includedir}/qpid/framing
%{_includedir}/qpid/sys
%{_includedir}/qpid/messaging
%{_includedir}/qpid/types
%{_libdir}/libqpidcommon.so
%{_libdir}/libqpidclient.so
%{_libdir}/libqpidtypes.so
%{_libdir}/libqpidmessaging.so
%{_libdir}/pkgconfig/qpid.pc
%{_libdir}/cmake/Qpid/QpidConfig.cmake
%{_libdir}/cmake/Qpid/QpidConfigVersion.cmake
%{_datadir}/qpid/examples/messaging
%defattr(755,root,root,-)
%{_libexecdir}/qpid/tests/qpid-perftest
%{_libexecdir}/qpid/tests/qpid-topic-listener
%{_libexecdir}/qpid/tests/qpid-topic-publisher
%{_libexecdir}/qpid/tests/qpid-latency-test
%{_libexecdir}/qpid/tests/qpid-client-test
%{_libexecdir}/qpid/tests/qpid-txtest
%{_libexecdir}/qpid/tests/qpid-ping
%{_libexecdir}/qpid/tests/qpid-txtest2
%{_libexecdir}/qpid/tests/receiver
%{_libexecdir}/qpid/tests/sender
%{_bindir}/qpid-send
%{_bindir}/qpid-receive

%post client-devel
/sbin/ldconfig

%postun client-devel
/sbin/ldconfig


%package client-docs
Summary:   AMQP client development documentation
BuildArch: noarch
Obsoletes: %{name}-client-devel-docs

%description client-docs
This package includes the AMQP clients development documentation in HTML
format for easy browsing.

%files client-docs
%defattr(-,root,root,-)
%doc %{_pkgdocdir}

%package server
Summary:   An AMQP message broker daemon
%if 0%{?fedora}
Provides:  qpid(cpp-server)%{?_isa} = %{version}-%{release}
Requires:  qpid(cpp-client)%{?_isa} = %{version}-%{release}
%endif
Requires:  %{name}-client = %{version}-%{release}
Requires:  cyrus-sasl
Requires:  qpid-proton-c%{?_isa} >= %{proton_min_ver}
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%endif
Obsoletes: %{name}-server-ssl
Obsoletes: %{name}-server-devel

%description server
A message broker daemon that receives stores and routes messages using
the open AMQP messaging protocol.

%files server
%defattr(-,root,root,-)
%{_libdir}/libqpidbroker.so*
%{_sbindir}/qpidd
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
%{_unitdir}/qpidd.service
%else
%{_initrddir}/qpidd
%endif
%config(noreplace) %{_sysconfdir}/qpid/qpidd.conf
%config(noreplace) %{_sysconfdir}/sasl2/qpidd.conf
%dir %{_libdir}/qpid/daemon
%{_libdir}/qpid/daemon/amqp.so
%attr(755, qpidd, qpidd) %dir %{_localstatedir}/lib/qpidd
%attr(600, qpidd, qpidd) %config(noreplace) %_localstatedir/lib/qpidd/qpidd.sasldb
%attr(755, qpidd, qpidd) %dir %{_localstatedir}/run/qpidd
%doc %{_mandir}/man1/qpidd*

%pre server
getent group qpidd >/dev/null || groupadd -r qpidd
getent passwd qpidd >/dev/null || \
  useradd -r -M -g qpidd -d %{_localstatedir}/lib/qpidd -s /sbin/nologin \
    -c "Owner of Qpidd Daemons" qpidd
exit 0

%post server
%if (0%{?rhel} && 0%{?rhel} < 7)
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add qpidd
/sbin/ldconfig
%else
%systemd_post qpidd.service
%endif 

%preun server
%if (0%{?rhel} && 0%{?rhel} < 7)
# Check that this is actual deinstallation, not just removing for upgrade.
if [ $1 = 0 ]; then
  /sbin/service qpidd stop >/dev/null 2>&1 || :
  /sbin/chkconfig --del qpidd
fi
%else
%systemd_preun qpidd.service
%endif

%postun server
%if (0%{?rhel} && 0%{?rhel} < 7)
if [ "$1" -ge "1" ]; then
  /sbin/service qpidd condrestart >/dev/null 2>&1 || :
fi
%else
%systemd_postun_with_restart qpidd.service
%endif
/sbin/ldconfig


%package server-ha
Summary: Provides extensions to the AMQP message broker to provide high availability
%if 0%{?fedora}
Provides: qpid(cpp-server-ha)%{?_isa} = %{version}-%{release}
Requires: qpid(cpp-server)%{?_isa} = %{version}-%{release}
%endif
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Obsoletes: %{name}-server-cluster

%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
# for systemd
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%endif

%description server-ha
%{summary}.

%files server-ha
%defattr(-,root,root,-)
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
%{_unitdir}/qpidd-primary.service
%else
%{_initrddir}/qpidd-primary
%endif
%{_libdir}/qpid/daemon/ha.so

%post server-ha
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
%systemd_post qpidd-primary.service
%else
/sbin/chkconfig --add qpidd-primary
%endif
/sbin/ldconfig

%preun server-ha
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
%systemd_preun qpidd-primary.service
%else
if [ $1 = 0 ]; then
  /sbin/service qpidd-primary stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del qpidd-primary
fi
%endif

%postun server-ha
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
%systemd_postun_with_restart qpidd-primary.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service qpidd-primary condrestart >/dev/null 2>&1 || :
fi
%endif
/sbin/ldconfig


%ifnarch s390 s390x
%package client-rdma
Summary:  RDMA Protocol support (including Infiniband) for Qpid clients
%if 0%{?fedora}
Provides: qpid(cpp-client-rdma)%{?_isa} = %{version}-%{release}
Requires: qpid(cpp-client)%{?_isa} = %{version}-%{release}
%endif
Requires: %{name}-client = %{version}-%{release}

%description client-rdma
A client plugin and support library to support RDMA protocols (including
Infiniband) as the transport for Qpid messaging.

%files client-rdma
%defattr(-,root,root,-)
%{_libdir}/librdmawrap.so*
%{_libdir}/qpid/client/rdmaconnector.so*
%config(noreplace) %{_sysconfdir}/qpid/qpidc.conf

%post client-rdma
/sbin/ldconfig

%postun client-rdma
/sbin/ldconfig


%package server-rdma
Summary:   RDMA Protocol support (including Infiniband) for the Qpid daemon
%if 0%{?fedora}
Provides: qpid(cpp-server-rdma)%{?_isa} = %{version}-%{release}
Requires: qpid(cpp-server)%{?_isa} = %{version}-%{release}
Requires: qpid(cpp-client-rdma)%{?_isa} = %{version}-%{release}
%endif
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Requires: %{name}-client-rdma = %{version}-%{release}

%description server-rdma
A Qpid daemon plugin to support RDMA protocols (including Infiniband) as the
transport for AMQP messaging.

%files server-rdma
%defattr(-,root,root,-)
%{_libdir}/qpid/daemon/rdma.so

%post server-rdma
/sbin/ldconfig

%postun server-rdma
/sbin/ldconfig
%endif

%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} < 7)
%package server-xml
Summary:  XML extensions for the Qpid daemon
%if 0%{?fedora}
Provides: qpid(cpp-server-xml)%{?_isa} = %{version}-%{release}
Requires: qpid(cpp-server)%{?_isa} = %{version}-%{release}
%endif
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Requires: xqilla
Requires: xerces-c

%description server-xml
A Qpid daemon plugin to support extended XML-based routing of AMQP
messages.

%files server-xml
%{_libdir}/qpid/daemon/xml.so

%post server-xml
/sbin/ldconfig

%postun server-xml
/sbin/ldconfig
%endif


%package server-linearstore
Summary: Red Hat persistence extension to the Qpid messaging sytem
%if 0%{?fedora}
Provides: qpid(cpp-server-lineastore)%{?_isa} = %{version}-%{release}
Requires: qpid(cpp-server)%{?_isa} = %{version}-%{release}
%endif
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
%if 0%{?fedora}
Requires: libdb4
%endif
%if (0%{?rhel} && 0%{?rhel} == 7)
Requires: libdb
%endif
%if (0%{?rhel} && 0%{?rhel} < 7)
Requires: db4
%endif
Requires: libaio
Obsoletes: rhm
Obsoletes: %{name}-server-store
Conflicts: %{name}-server-store

%description server-linearstore
Red Hat persistence extension to the Qpid AMQP broker: persistent message
storage using a libaio-based asynchronous journal.

%files server-linearstore
%defattr(-,root,root,-)
%{_libdir}/qpid/daemon/linearstore.so
%{_libdir}/liblinearstoreutils.so

%post server-linearstore
/sbin/ldconfig

%postun server-linearstore
/sbin/ldconfig

%if 0%{?fedora}
%package -n perl-qpid-messaging
Summary:  Perl bindings for the Qpid messaging framework

Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires: qpid-cpp-client = %{version}-%{release}

%description -n perl-qpid-messaging
%{summary}.

%files -n perl-qpid-messaging
%{perl_vendorarch}/*
%doc LICENSE.txt
%doc %{_perldocdir}


%package -n python-qpid-messaging
Summary: Python bindings for the Qpid messaging framework

Requires: python
Requires: qpid(cpp-client)%{?_isa} = %{version}-%{release}
Requires: python-qpid >= 1.35.0

%{?filter_setup:
  %filter_provides_in %{python_sitearch}/.*\.so$
  %filter_setup}

%description -n python-qpid-messaging
%{summary}.

%files -n python-qpid-messaging
%doc LICENSE.txt
%{python2_sitearch}/qpid_messaging.py*
%{python2_sitearch}/_qpid_messaging.so
%{_pythondocdir}/examples
%endif


%package -n qpid-tools
Summary:  Management and diagostic tools for Apache Qpid
BuildArch: noarch

Requires:  python-qpid >= 1.35.0
Requires:  python-qpid-qmf = %{version}-%{release}

%description -n qpid-tools
Management and diagnostic tools for Apache Qpid brokers and clients.

%files -n qpid-tools
%{_bindir}/qpid-config
%{_bindir}/qpid-ha
%{_bindir}/qpid-printevents
%{_bindir}/qpid-queue-stats
%{_bindir}/qpid-route
%{_bindir}/qpid-stat
%{_bindir}/qpid-tool
%{python_sitelib}/qpidtoollibs
%{_libexecdir}/qpid-qls-analyze
%dir %{_datadir}/qpid-tools
%dir %{_datadir}/qpid-tools/python
%{_datadir}/qpid-tools/python/qlslibs
%doc NOTICE.txt
%doc LICENSE.txt

%if "%{python_version}" >= "2.6"
%{python_sitelib}/qpid_tools-*.egg-info
%endif


%package -n qpid-qmf
Summary: The QPID Management Framework
%if 0%{?fedora}
Requires:  qpid(cpp-client)%{?_isa}
%endif
Requires:  qpid-cpp-client%{?_isa} = %{version}-%{release} 
Obsoletes: qpid-qmf-debuginfo

%description -n qpid-qmf
The Qpid Management Framework is a general-purpose management bus built on Qpid
messaging. It takes advantage of the scalability, security, and rich
capabilities of Qpid to provide flexible and easy-to-use manageability to a
large set of applications.

%files -n qpid-qmf
%{_libdir}/libqmf2.so.*

%post -n qpid-qmf
/sbin/ldconfig

%postun -n qpid-qmf
/sbin/ldconfig


%package -n qpid-qmf-devel
Summary:   Header files and tools for developing QMF extensions
Requires:  qpid-qmf%{?_isa} = %{version}-%{release}
%if 0%{?fedora}
Requires:  qpid(cpp-client-devel)%{?_isa}
%endif
Requires:  qpid-cpp-client-devel%{?_isa} = %{version}-%{release}
Obsoletes: qpid-qmf-debuginfo

%description -n qpid-qmf-devel
Header files and code-generation tools needed for developers of QMF-managed
components.

%files -n qpid-qmf-devel
%{_includedir}/qmf
%{_libdir}/libqmf2.so
%{_bindir}/qmf-gen
%{python_sitelib}/qmfgen
%{_libdir}/pkgconfig/qmf2.pc

%post -n qpid-qmf-devel
/sbin/ldconfig

%postun -n qpid-qmf-devel
/sbin/ldconfig


%package -n python-qpid-qmf
Summary:   The QPID Management Framework bindings for python

Requires:  qpid-qmf%{?_isa} = %{version}-%{release}
Requires:  %{name}-client%{?_isa} = %{version}-%{release}

%description -n python-qpid-qmf
An extensible management framework layered on QPID messaging, bindings
for python.

%files -n python-qpid-qmf
%{python_sitelib}/qmf
%exclude %{python_sitelib}/qmf/*.pyc
%exclude %{python_sitelib}/qmf/*.pyo
%{python_sitearch}/qmf2.py*
%{python_sitearch}/cqmf2.py*
%{python_sitearch}/_cqmf2.so

%post -n python-qpid-qmf
/sbin/ldconfig

%postun -n python-qpid-qmf
/sbin/ldconfig


%if 0%{?fedora} || 0%{?rhel}
%package -n ruby-qpid-qmf
Summary:   The QPID Management Framework bindings for ruby

Requires:  qpid-qmf%{?_isa} = %{version}-%{release}

%description -n ruby-qpid-qmf
An extensible management framework layered on QPID messaging, bindings
for ruby.

%files -n ruby-qpid-qmf
%defattr(-,root,root,-)
%{ruby_vendorlibdir}/qmf2.rb
%{ruby_vendorarchdir}/cqpid.so
%{ruby_vendorarchdir}/cqmf2.so

%post -n ruby-qpid-qmf
/sbin/ldconfig

%postun -n ruby-qpid-qmf
/sbin/ldconfig
%endif

%prep
%setup -q -n qpid-cpp-%{version}

%patch0 -p1
%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
%patch1 -p3
%endif
%if 0%{?fedora}
%patch2 -p3
%patch3 -p3
%endif

%build

CXX11FLAG="-std=c++11"

%if (0%{?rhel} && 0%{?rhel} <= 6)
CXX11FLAG="-w"
%endif

%if 0%{?fedora}
%cmake -DDOC_INSTALL_DIR:PATH=%{_pkgdocdir} \
       -DBUILD_LEGACYSTORE=false \
       -DBUILD_LINEARSTORE=true \
       -DPERL_PFX_ARCHLIB=%{perl_vendorarch} \
       -DBUILD_BINDING_RUBY=true \
       "-DCMAKE_CXX_FLAGS=$CXX11FLAG $CXXFLAGS" \
       .
%endif
%if 0%{?rhel}
%cmake  -DDOC_INSTALL_DIR:PATH=%{_pkgdocdir} \
        -DBUILD_LEGACYSTORE=false \
        -DBUILD_LINEARSTORE=true \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCMAKE_EXE_LINKER_FLAGS="-Wl,-z,relro,-z,now" \
        -DCMAKE_SHARED_LINKER_FLAGS="-Wl,-z,relro" \
        -DCMAKE_MODULE_LINKER_FLAGS="-Wl,-z,relro" \
       "-DCMAKE_CXX_FLAGS=$CXX11FLAG $CXXFLAGS" \
        .
%endif

make %{?_smp_mflags}
make docs-user-api

%install
rm -rf %{buildroot}

pushd management/python
%{__python} setup.py install \
    --install-purelib %{python_sitelib} \
    --root %{buildroot}
popd

chmod +x %{buildroot}/%{python_sitelib}/qpidtoollibs/disp.py

mkdir -p -m0755 %{buildroot}/%{_bindir}
mkdir -p -m0755 %{buildroot}/%{_unitdir}

%if 0%{?fedora}
# install examples
mkdir -p -m0755 %{buildroot}%{_perldocdir}/examples
mkdir -p -m0755 %{buildroot}%{_pythondocdir}/examples

pushd bindings/qpid/examples/python
install -pm 644 * %{buildroot}%{_perldocdir}/examples
install -pm 644 * %{buildroot}%{_pythondocdir}/examples
popd
%endif

%make_install

# enable auth by default
echo "auth=yes" >> %{buildroot}/etc/qpid/qpidd.conf

%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
# install systemd files
mkdir -p %{buildroot}/%{_unitdir}
install -pm 644 %{_builddir}/qpid-cpp-%{version}/etc/qpidd.service \
    %{buildroot}/%{_unitdir}
install -pm 644 %{_builddir}/qpid-cpp-%{version}/etc/qpidd-primary.service \
    %{buildroot}/%{_unitdir}
%endif

install -d -m0755 %{buildroot}%{_localstatedir}/lib/qpidd
install -m0600 %{_sourcedir}/qpidd.sasldb %{buildroot}%{_localstatedir}/lib/qpidd
install -d -m0755 %{buildroot}%_libdir/qpid
install -d -m0755 %{buildroot}/var/run/qpidd

# Set executable bit on shared libraries to ensure the binaries are stripped
chmod +x %{buildroot}/%{python_sitearch}/*so

# QMF Python management
install -d %{_builddir}/qpid-cpp-%{version}/managementgen/qmfgen \
           %{buildroot}/%{python_sitelib}

%if 0%{?fedora} || 0%{?rhel}
# QMF Ruby package
install -d %{buildroot}%{ruby_vendorlibdir}
install -d %{buildroot}%{ruby_vendorarchdir}

install -pm 644 %{_builddir}/qpid-cpp-%{version}/bindings/qmf2/ruby/qmf2.rb \
    %{buildroot}%{ruby_vendorlibdir}
%endif

%if 0%{?fedora} || 0%{?rhel}
install -pm 755 %{_builddir}/qpid-cpp-%{version}/bindings/qpid/ruby/libcqpid_ruby.so \
     %{buildroot}%{ruby_vendorarchdir}/cqpid.so
install -pm 755 %{_builddir}/qpid-cpp-%{version}/bindings/qmf2/ruby/libcqmf2_ruby.so \
    %{buildroot}%{ruby_vendorarchdir}/cqmf2.so
%endif

%if 0%{?fedora} || (0%{?rhel} && 0%{?rhel} >= 7)
rm -f %{buildroot}/%{_initrddir}/qpidd*
%endif
rm -f %{buildroot}/%{_libdir}/qpid/daemon/store.so*

# clean up leftover examples files:
rm -f %{buildroot}/%{_datadir}/qpid/examples/README.txt
rm -f %{buildroot}/%{_datadir}/qpid/examples/qmf2/agent.cpp
rm -f %{buildroot}/%{_datadir}/qpid/examples/qmf2/event_driven_list_agents.cpp
rm -f %{buildroot}/%{_datadir}/qpid/examples/qmf2/list_agents.cpp
rm -f %{buildroot}/%{_datadir}/qpid/examples/qmf2/print_events.cpp

# clean up leftover ruby files
%if (0%{?rhel} && 0%{?rhel} <= 6)
rm -fr %{buildroot}/usr/%{_lib}/ruby/site_ruby
%else
rm -rf %{buildroot}/usr/local/%{_lib}/ruby/site_ruby
%endif

# clean up rhel build
%if 0%{?rhel}
rm -f  %{buildroot}/%{python_sitearch}/_qpid_messaging.so
rm -f  %{buildroot}/%{python_sitearch}/qpid_messaging.py*
# These bits will be build if perl-devel package is installed
rm -fr %{buildroot}%_libdir/perl5
%endif

%clean
rm -rf %{buildroot}

%post
/sbin/ldconfig

%postun
/sbin/ldconfig


%changelog
* Tue May 8 2018 Mike Cressman <mcressma@redhat.com> - 1.36.0-18
- BZ-1561819,QPID-8184 - fix linearstore crash during journal recovery
- only require qpid-proton-0.16.0 or later for now

* Mon Apr 30 2018 Mike Cressman <mcressma@redhat.com> - 1.36.0-17
- require qpid-proton-0.16.0-11 or later

* Fri Apr 27 2018 Mike Cressman <mcressma@redhat.com> - 1.36.0-16
- BZ-1572502,QPID-8118: check device list before freeing (rdma-related)

* Tue Apr 24 2018 Mike Cressman <mcressma@redhat.com> - 1.36.0-15
- BZ-1564132,QPID-7991 - fix bug that could cause valid bridges to be deleted

* Tue Jan 9 2018 Mike Cressman <mcressma@redhat.com> - 1.36.0-14
- BZ-1529929 - start link heartbeat timer sooner (and redundantly)

* Fri Nov 3 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-13
- BZ-1507610,QPID-7901 - HA cluster infinite ping-pong of session.detach "invalid session name" errors

* Wed Oct 18 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-12
- BZ-1502855,QPID-7975 - fix state machine in flush timer

* Fri Sep 29 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-11
- QPID-7895 - fix another race condition in flush timer

* Tue Aug 29 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-9
- QPID-7895 - further updates for possible race conditions in flush timer

* Wed Aug 23 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-8
- QPID-7859,ENTMQCL-511 - fix exception handling for reject when routing
  through exchange
- QPID-7847 - support reconnect in qmf BrokerAgent
- QPID-7895 - make linearstore flush timer more efficient

* Fri Jul 7 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-7
- BZ 1443470 - correctly clean up empty file pool when deleting a durable queue
- BZ 1450495 - fix qpidd segfault during startup when SSL cert can't be read

* Tue May 23 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-6
- build ruby-qpid-qmf on rhel
- obsolete qpid-qmf-debuginfo (now contained in qpid-cpp-debuginfo)

* Thu Apr 13 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-5
- fix multilib problem with qmf

* Wed Apr 12 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-4
- update .so's for 1.36.0

* Wed Apr 12 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-3
- update spec file for MRG downstream

* Thu Mar 30 2017 Mike Cressman <mcressma@redhat.com> - 1.36.0-1
- Rebase to 1.36.0, plus:
- QPID-7666 - more flexibility for linearstore configuration
- QPID-7679 - fix memory leak on DirectExchange::unbind
- QPID-7677 - add --session-max-unacked to configure buffer per amqp 1.0 Session
- BZ 1324845 - federation does not interoperate between MRG-M 2 and 3

* Fri Feb 24 2017 Mike Cressman <mcressman@redhat.com> - 0.34-21
- Resolved: 1425576

* Thu Dec 1 2016 Mike Cressman <mcressman@redhat.com> - 0.34-20
- Fixed bad patch file line endings

* Mon Nov 21 2016 Mike Cressman <mcressman@redhat.com> - 0.34-19
- Resolved: 1396281

* Fri Aug 5 2016 Mike Cressman <mcressman@redhat.com> - 0.34-17
- Resolved: 1330539, 1359506

* Mon Aug 1 2016 Mike Cressman <mcressman@redhat.com> - 0.34-16
- Resolved: 1333767, 1350023

* Thu Jun 23 2016 Mike Cressman <mcressman@redhat.com> - 0.34-15
- Resolved: 1146849, 1333767

* Wed May 25 2016 Mike Cressman <mcressman@redhat.com> - 0.34-12
- Resolved: 1330539, 1339449

* Wed May 11 2016 Mike Cressman <mcressman@redhat.com> - 0.34-11
- Resolved: 1330539, 1333437, 1333767

* Tue Apr 26 2016 Mike Cressman <mcressman@redhat.com> - 0.34-10
- Resolved: 1329582

* Fri Apr 15 2016 Mike Cressman <mcressman@redhat.com> - 0.34-9
- Resolved: 1316507, 1318180, 1324845

* Fri Mar 18 2016 Mike Cressman <mcressman@redhat.com> - 0.34-8
- Resolved: 1316507

* Fri Feb 19 2016 Irina Boverman <iboverma@redhat.com> - 0.34-7
- Rebuilt against proton 0.12.0
- Added -DCMAKE_CXX_FLAGS=-Wno-error=switch (to be removed in 0.35)

* Tue Jan 26 2016 Mike Cressman <mcressman@redhat.com> - 0.34-6
- Resolved: 1301359

* Fri Sep 18 2015 Irina Boverman <iboverma@redhat.com> - 0.34-5
- Resolved: 1261180

* Fri Sep 11 2015 Irina Boverman <iboverma@redhat.com> - 0.34-4
- Resolved: 1095849, 1254948, 1258971, 1258993, 1261187

* Tue Sep  1 2015 Irina Boverman <iboverma@redhat.com> - 0.34-3
- Resolved: 1151446, 1237054, 1240552, 1254944, 1254948, 1258993

* Tue Aug 18 2015 Irina Boverman <iboverma@redhat.com> - 0.34-2
- Built agaist qpid-proton 0.10-1
- Resolved: 1234423, 1245184, 1248430

* Wed Jul  1 2015 Irina Boverman <iboverma@redhat.com> - 0.34-1
- Rebased to 0.34 upstream release
- Updated .so versions
- Built against qpid-proton-0.9-4

* Thu Jun 18 2015 Irina Boverman <iboverma@redhat.com> - 0.32-5
- Added "Requires: libuuid-devel"

* Wed Jun 17 2015 Irina Boverman <iboverma@redhat.com> - 0.32-4
- Removed "Requires: boost-devel"

* Fri May 29 2015 Irina Boverman <iboverma@redhat.com> - 0.32-3
- Resolved: 1002605, 1224300

* Tue Apr 14 2015 Irina Boverman <iboverma@redhat.com> - 0.32-1
- Rebased to 0.32 upstream
- Resolved: 1015448, 1066256, 1081162, 1082591, 1112850,         
  1128783, 1131720, 1136418, 1145145, 1148807, 1150127,
  1151446, 1152012, 1152032, 1155540, 1160367, 1165200,
  1167911

* Tue Mar 31 2015 Irina Boverman <iboverma@redhat.com> - 0.30-8
- Resolved: 1179341, 1202376
- Rebuilt against qpid-proton-0.9-2

* Tue Mar 10 2015 Irina Boverman <iboverma@redhat.com> - 0.30-7
- Resolved: 1187636, 1193170, 1194777

* Tue Feb  3 2015 Irina Boverman <iboverma@redhat.com> - 0.30-6
- Resolved: 985870, 1179609, 1184124, 1186693         

* Tue Jan 13 2015 Irina Boverman <iboverma@redhat.com> - 0.30-5
- Resolved: 985870, 1095849, 1145386, 1160232, 1163650, 995496, 
  1089652, 1147977, 1158903, 1158906, 1158910, 1160154
- Added changes needed to build Windows client
- Added option to build linearstore and disabled legacystore build
- Initial build using qpid-cpp-0.30.tar.gz     

* Fri Sep 12 2014 Irina Boverman <iboverma@redhat.com> - 0.22-49
- Resolved: 1139351

* Fri Aug 29 2014 Irina Boverman <iboverma@redhat.com> - 0.22-48
- Resolved: 1128051, 1132350, 1132427, 1133948, 1129997 (partial)

* Fri Aug 22 2014 Irina Boverman <iboverma@redhat.com> - 0.22-47
- Resolved: 1051555, 1117708, 1128653, 1129277, 1130467,
  1129997 (partial)

* Fri Aug  8 2014 Irina Boverman <iboverma@redhat.com> - 0.22-46
- Resolved: 1121660, 1122928, 1122966, 1126952, 1127089

* Fri Aug  1 2014 Irina Boverman <iboverma@redhat.com> - 0.22-45
- Resolved: 1117823, 1121623, 1124906

* Wed Jul 23 2014 Irina Boverman <iboverma@redhat.com> - 0.22-44
- Resolved: 1011221, 1086638, 1117745

* Tue Jul 15 2014 Irina Boverman <iboverma@redhat.com> - 0.22-43
- Resolved: 1090376, 1090395

* Fri Jun  6 2014 Irina Boverman <iboverma@redhat.com> - 0.22-42
- Resolved: 1098118, 1105221

* Fri May 23 2014 Irina Boverman <iboverma@redhat.com> - 0.22-41
- Resolved: 1091639, 1098118, 1100402, 1100442

* Fri May 16 2014 Irina Boverman <iboverma@redhat.com> - 0.22-40
- Resolved: 1076392, 1078142, 1082487, 1090368, 1091558, 1091638,
  1091639, 1097559, 1097848 

* Fri Apr 25 2014 Irina Boverman <iboverma@redhat.com> - 0.22-38
- Resolved: 1061736, 1066180, 1076545, 1085053, 1086638, 1087827,
  1075223, 1077384      

* Fri Apr  4 2014 Irina Boverman <iboverma@redhat.com> - 0.22-37
- Resolved: 1052046, 1071222, 1072469, 1075223, 1077384

* Fri Mar  7 2014 Irina Boverman <iboverma@redhat.com> - 0.22-36
- Resolved: 1015291, 1039550, 1044001, 1063700, 1064181, 1069743

* Mon Feb 10 2014 Irina Boverman <iboverma@redhat.com> - 0.22-35
- Added patches to be consistent with qpid-cpp 0.22-35 on RHEL 6

* Mon Jan 13 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.22-31
- Added support for systemd 
- Updated qpid-cpp-server-ha to be a systemd service

* Fri Nov 22 2013 Irina Boverman <iboverma@redhat.com> - 0.22-29
- Resolved Windows build problem

* Fri Nov 22 2013 Irina Boverman <iboverma@redhat.com> - 0.22-27
- Resolved: 709325, 1007819, 1026483, 1030219, 1031617, 1032582 	

* Fri Nov 15 2013 Irina Boverman <iboverma@redhat.com> - 0.22-26
- Added -DCMAKE_MODULE_LINKER_FLAGS=-Wl,-z,relro to cmake
- Resolved: 1019189, 1021941, 1027385, 1027391, 1029418, 1029426, 
  1029428, 1029432, 1029437, 1029440, 1029442, 1029446

* Wed Nov  6 2013 Irina Boverman <iboverma@redhat.com> - 0.22-25
- Removed qpid-cpp-tar package
- Resolved: 996249, 1010584, 1019189, 1019432, 1023641, 1024385, 
  1024396, 1024944, 1024957, 1024972, 1025381, 1025693, 1025771,
  1025828, 1026327, 1026354

* Fri Oct 25 2013 Irina Boverman <iboverma@redhat.com> - 0.22-23
- Resolved: 1023083, 1023418

* Thu Oct 24 2013 Irina Boverman <iboverma@redhat.com> - 0.22-22
- Resolved: 1018749, 1021569, 1021609, 1021616

* Mon Oct 21 2013 Irina Boverman <iboverma@redhat.com> - 0.22-21
- Resolved: 927444

* Fri Oct 18 2013 Irina Boverman <iboverma@redhat.com> - 0.22-20
- Resolved: 990972, 1002954, 1018746, 1018749, 1018765, 1018845, 1019150, 1019180, 1019181, 1019236, 1019404, 1019645 

* Fri Oct 11 2013 Irina Boverman <iboverma@redhat.com> - 0.22-19
- Resolved: 995554, 1004838, 1005736, 1012852, 1014076, 1014163, 1017113 
- Removed amqpc.so library

* Fri Sep 27 2013 Irina Boverman <iboverma@redhat.com> - 0.22-18
- Added changes to support bz995554

* Thu Sep 26 2013 Irina Boverman <iboverma@redhat.com> - 0.22-17
- Resolved bz(s): 915821, 955688, 955688, 1009454, 1009467, 1009525, 1009816, 1010390, 1010393, 1010395, 1010955, 1011519, 1011631, 1011902

* Fri Sep 20 2013 Irina Boverman <iboverma@redhat.com> - 0.22-16
- Resolved bz(s): 969039, 974061, 987961, 995039, 1009422

* Fri Sep 13 2013 Irina Boverman <iboverma@redhat.com> - 0.22-14
- Resolved bz(s): 949739, 971894, 987961, 995039, 1003674, 1004002, 1004474, 1006962, 1006976, 1006980
- Removed .../qpid/amqp_0_10, .../qpid/log, .../qpid/management from client-devel package (removed from source)

* Tue Sep  3 2013 Irina Boverman <iboverma@redhat.com> - 0.22-13
- Changed qpid-proton... >= 0.5

* Fri Aug 30 2013 Irina Boverman <iboverma@redhat.com> - 0.22-12
- Resolved bz(s): 967734, 981636, 997919, 999505, 1000587, 1001772

* Thu Aug 15 2013 Irina Boverman <iboverma@redhat.com> - 0.22-11
- Resolves bz: 966944, 996057, 996075, 996078, 996092, 996094, 996100, 996573 

* Fri Aug  9 2013 Irina Boverman <iboverma@redhat.com> - 0.22-10
- Resolved bz: 453533, 691411, 874516, 977290 (windows build), 990972

* Thu Aug  1 2013 Irina Boverman <iboverma@redhat.com> - 0.22-9
- Resolved bz: 987961 (windows build)

* Thu Jul 25 2013 Irina Boverman <iboverma@redhat.com> - 0.22-8
- Resolved bz(s): 894375, 985919, 987535 

* Wed Jul 10 2013 Irina Boverman <iboverma@redhat.com> - 0.22-7
- Changed /etc/qpidd.conf to /etc/qpid/qpidd.conf
- Added doxygen/make docs-user-api and removed Source2
- Resolved bz(s): 768114, 888501, 916953, 953662, 975046, 977820, 977891, 979385, 981638, 981640, 981642, 983514, 983517 

* Fri Jun 28 2013 Irina Boverman <iboverma@redhat.com> - 0.22-6
- Resolved bz(s): 976398, 978379, 978468, 978902, 975949, 959447, 970748 and 975937

* Fri Jun 21 2013 Irina Boverman <iboverma@redhat.com> - 0.22-5
- Resolved bz(s): 975422, 975423, 975430, 975434, 975444, 975446, 975451, 975460, 975463 and 975088 

* Wed Jun 19 2013 Irina Boverman <iboverma@redhat.com> - 0.22-4
- Added qpid-send and qpid-receive to (a) be part of the -devel package and (b) get installed to /usr/bin.

* Thu Jun 13 2013 Irina Boverman <iboverma@redhat.com> - 0.22-4
- Updated to include qpid-cpp-doxygen-0.22.html.tar.gz

* Tue Jun 11 2013 Irina Boverman <iboverma@redhat.com> - 0.22-3
- Updated source tarball and added fixes for these BZ(s):
  928951, 808105, 953662, 949014, 865689, 733758, 906814,
  739863, 862899, 703891, 796765, 889552, 797092, 453533, 
  970748, 901590, 902312, 955578, 958444, 970748, 825075, 
  588504, 955674, 782070, 959447, 961014, 959452, 928935, 
  963245, 963367, 691411, 970748, 970748, 957871, 964224, 
  963243, 963244, 964228, 969049, 962311
- Added fixes for qpid-sdk:
  715284, 846671, 905661 

* Thu May 30 2013 Irina Boverman <iboverma@redhat.com> - 0.22-2
- Added qpid-cpp-tar package to generate a tarball for Windows SDK build

* Mon May  6 2013 Irina Boverman <iboverma@redhat.com> - 0.22-2
- Resolved problem with shared library versions

* Fri Apr 19 2013 Irina Boverman <iboverma@redhat.com> - 0.22-1
- Made changes for 0.22/cmake based build

* Thu Jan 24 2013 Mike Cressman <mcressman@redhat.com> - 0.18-14
- consolidated the store patch files, now using the new 0.18 store branch
  (no code changes)
- BZs: 835119,884036,887044,896451
- HA BZs: 883548,886262,886656

* Wed Dec 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-13
- BZs: 846465
- new HA regression BZs: 861162,882149,882373,883548,884036,885658

* Tue Dec 4 2012 Mike Cressman <mcressman@redhat.com> - 0.18-12
- BZs: 872392,872946,877553,878638
- added another store patch(5) with updated generated qmf files

* Tue Nov 27 2012 Mike Cressman <mcressman@redhat.com> - 0.18-11
- HA BZs: 876688,876720,877081

* Tue Nov 20 2012 Mike Cressman <mcressman@redhat.com> - 0.18-10
- BZs: 875660, 876664
- HA BZs: 860701, 874192, 874118,874298
- remove faulty fix for 871100
- add new /etc/qpid/qpidd.acl
- qmf build cleanup
- add back deprecated fromString() that we must carry on MRG 2.x
  for compatibility

* Mon Nov 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-9
- HA BZs: 872696,873883,874118,874298

* Fri Nov 9 2012 Mike Cressman <mcressman@redhat.com> - 0.18-8
- BZs: 872172, 873465
- Fixed the windows build for 0.18

* Tue Nov 6 2012 Mike Cressman <mcressman@redhat.com> - 0.18-7
- BZs: 868881,873347
- HA BZs: 860701 - restore old qmf-1 interfaces, keeping new ones also
- store cleanup related to qmf changes

* Thu Nov 1 2012 Mike Cressman <mcressman@redhat.com> - 0.18-6
- BZs: 868951,871774
- HA BZs: 869002
- revert PACKAGE_NAME naming in generated qmf code

* Wed Oct 31 2012 Mike Cressman <mcressman@redhat.com> - 0.18-4
- BZs: 802656,804752,836141,861838,866677,868403,870058
- HA BZs: 860701,865524,867030,868360,868364,869420,871100
- updated store for new management interfaces

* Fri Oct 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-2
- BZs merged from 2.2: 609685,683711,689408,799269,831365
- New BZs: 861165,863349, HA BZs: 859170,860691,860704,865524,865846
- add perl/swig support files to client-devel
- updated man page

* Wed Oct 3 2012 Mike Cressman <mcressman@redhat.com> - 0.18-1
- rebase to 0.18
- update library revs

